@@ -40,7 +40,7 @@ from time import time
 import secrets
 import json
 
-__version__ = "0.0.1"
+__version__ = "0.0.4"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -123,6 +123,7 @@ class Argument(DefaultNamespace):
         "input",
         "example",
         "html_type",
+        "is_advanced",
         "description",
         "default_value",
         "predefined_values",
@@ -133,9 +134,11 @@ class Argument(DefaultNamespace):
         "description": None,
         "example": None,
         "input": None,
+        "is_advanced": False,
     }
     __types__ = {
         "predefined_values": list,
+        "is_advanced": bool,
         "input": bool,
         "list": bool,
     }
@@ -509,8 +512,8 @@ class ScriptConfig(DefaultNamespace):
         json_api = self.get_dict()
 
         for key in (
-            "documentation_file",
             "command_generate_documentation",
+            "documentation_file",
             "minimum_access",
             "access_groups",
             "access_users",
@@ -521,6 +524,9 @@ class ScriptConfig(DefaultNamespace):
         ):
             del json_api[key]
 
+        if "secrets" in json_api.keys():
+            del json_api["secrets"]
+
         arguments = json_api.pop("args")
         json_api["args"] = []
 
@@ -820,7 +826,7 @@ class TokenCSRF:
                 to_delete.append(token)
 
         for key in to_delete:
-            del user.csrf[token]
+            del user.csrf[key]
 
 
 class Session:
